@@ -28,6 +28,9 @@ from .api import (
     oap_get_users
 )
 from .utilities import is_authenticated
+import logging
+logger = logging.getLogger(__name__)
+
 
 
 _app_entry = """
@@ -143,6 +146,7 @@ class OAPDash(dash.Dash):
 
     def index(self, *args, **kwargs):  # pylint: disable=unused-argument
         if is_authenticated():
+            logging.error(f'oap_dash file  is_authentication if block')
             resp = self._index(args, kwargs)
             return resp
         else:
