@@ -326,9 +326,14 @@
 
 #==========================    Modified Code    ======================================
 import os
+import time
 import random
 import dateutil.parser
 from datetime import datetime
+import requests
+import logging
+logger = logging.getLogger(__name__)
+
 
 from openpyxl import Workbook
 from openpyxl.styles import PatternFill, Font, Alignment
@@ -342,16 +347,112 @@ from openpyxl.chart import (
     Series,
 )
 from openpyxl.chart.series import DataPoint
-app_name = os.getenv("PLATFORM_ROUTE")
+
+from analytics_sdk.utilities import (
+    BASE_API_URL,
+    PLATFORM_ROUTE,
+    API_KEY,
+    API_SECRET,
+    API_RETRY
+    )
+
+#app_name = os.getenv("PLATFORM_ROUTE")
 
 class ExcelRenderer:
     ROW_START = 3
-    def __init__(self, analysis_run):
+    global res
+    res = ''
+    def __init__(self, analysis_run, tenantId):
         """
         :param analysis_run: AnalysisRun
         """
         self.wb = Workbook()
         self.analysis_run = analysis_run
+        #self.tenantId = tenantId
+        
+        def get_token():
+            headers = {"Content-Type" : "application/x-www-form-urlencoded" , "Accept" : "application/json"};
+            post_data = {"grant_type": "client_credentials", "client_id" : API_KEY, "client_secret" : API_SECRET};
+            token_url = BASE_API_URL + "/auth/oauth/token";
+            response = requests.post(token_url,data=post_data,headers=headers,verify=False);
+            json = response.json();
+            auth = str(json["access_token"])
+            return auth
+
+
+        def get_headers():
+            headers = {
+                            'Content-Type': 'application/json',
+                            'Accept': 'application/json',
+                            'Authorization': f'Bearer {get_token()}'
+                        }
+
+            return headers
+
+        def call_requests(method, url, params=None, data=None, json=None, verify=True):
+            headers = get_headers()
+            retry = 1
+            resp = None
+            while retry <= API_RETRY:
+                try:
+                    resp = requests.request(method, url, params=params, data=data, json=json, headers=headers, verify=verify)
+                    if not resp.ok:
+                        time.sleep(retry * 2)
+                        retry+=1
+                        continue
+                except requests.exceptions.ConnectionError:
+                    time.sleep(retry * 2)
+                    retry+=1
+                    continue
+
+                return resp
+
+            return resp
+
+        #def call_get_requests(url, params=None, verify=True):
+        #    return call_requests('GET', url, params, verify=verify)
+
+        url = BASE_API_URL + f'/analyticsapps/api/v7/tenants/{tenantId}/analysisrun/{analysis_run}/summary'
+        #res = call_requests('GET', url)
+        res = {
+            "analysisRun": {
+                "name": "test analysis run11",
+                "installedAppId": "INTG-b6313fb2-5196-4da5-9553-c934ed54g161595",
+                "triggeredBy": "USR0000000005",
+                "isSavedAnalysis": "true",
+            "analysis": {
+                "name": "analysis for run11",
+                "partnerName": "United Services",
+                "partnerId": "msp_3",
+                "createdBy": {
+                    "loginName": "uadmin",
+                    "id": 0,
+                    "version": 0,
+                    "uuid": "USR0000000005"
+                    },
+                "id": "analysis-7ffe7ffe-7526-481b-91a2-beef2d7535de",
+                "version": 0,
+                "createdTime": "2022-03-08T10:18:32+0000"
+        },
+            "analysisConfig": {
+                "scheduleType": "ONDEMAND",
+                "analysisPeriod": "SPECIFIC",
+                "startTime": "2022-02-05T00:00:00+0000",
+                "endTime": "2022-03-01T23:59:59+0000",
+                "fileFormat": "PDF"
+        },
+            "id": "analysisrun-ab8b4ca8-7b34-4746-998e-1cf4ebc5f0db",
+            "version": 0
+            },
+        "genStime": 1644019200000,
+        "genEtime": 1646179199000,
+        "startTime": "2022-02-05T00:00:00+0000",
+        "endTime": "2022-03-01T23:59:59+0000"
+        }
+        #if res == None or not res.ok:
+        #    logger.info('Get excel summary is failed')
+        
+        self.res = res
 
     def _load_data(self, ws, data, row_start, col_start, adjust_column=True, x_axis_date_format=None):
         column_widths = {}
@@ -485,7 +586,7 @@ class ExcelRenderer:
 
         ws.add_chart(chart, chart_data['chart-position'])
 
-    def generate_summary(self):
+    def generate_summary(self, res):
         """
         add summary sheet
         """
@@ -501,7 +602,7 @@ class ExcelRenderer:
 
         ws.merge_cells('B3:Z4')
         cell = ws['B3']
-        cell.value = app_name
+        cell.value = PLATFORM_ROUTE
         cell.font = Font(color="00598B", bold=True)
         cell.alignment = Alignment(vertical="center")
         cell.fill = PatternFill("solid", fgColor="eeeeee")
@@ -518,7 +619,7 @@ class ExcelRenderer:
         cell.fill = PatternFill("solid", fgColor="eeeeee")
 
         cell = ws['C6']
-        cell.value = "Dec-11-analysis"
+        cell.value = res['analysisRun']['analysis']['partnerId']
         cell.font = Font(color="000000")
         cell.fill = PatternFill("solid", fgColor="eeeeee")
 
@@ -530,9 +631,10 @@ class ExcelRenderer:
 
         cell = ws['C7']
         # params = self.analysis_run.params
-        start_date = "2021-12-10T12:00:00"
-        end_date = "2021-12-11T12:00:00"
+        start_date = res['analysisRun']['analysisConfig']['startTime']
+        end_date = res['analysisRun']['analysisConfig']['endTime']
         cell.value = f'{start_date} - {end_date}'
+        #cell.value = f'{start_date.strftime("%B %d, %Y")} - {end_date.strftime("%B %d, %Y")}'
         cell.font = Font(color="000000")
         cell.fill = PatternFill("solid", fgColor="eeeeee")
 
@@ -548,7 +650,7 @@ class ExcelRenderer:
         cell.fill = PatternFill("solid", fgColor="eeeeee")
 
         cell = ws['C9']
-        cell.value = "Dec analysis"
+        cell.value = res['analysisRun']['analysis']['name']
         cell.font = Font(color="000000")
         cell.fill = PatternFill("solid", fgColor="eeeeee")
 
@@ -559,7 +661,7 @@ class ExcelRenderer:
         cell.fill = PatternFill("solid", fgColor="eeeeee")
 
         cell = ws['C10']
-        cell.value = "2021-12-11T12:00:00"
+        cell.value = res['startTime']
         cell.font = Font(color="000000")
         cell.fill = PatternFill("solid", fgColor="eeeeee")
 
@@ -570,7 +672,7 @@ class ExcelRenderer:
         cell.fill = PatternFill("solid", fgColor="eeeeee")
 
         cell = ws['C11']
-        cell.value = "2021-12-12T12:00:00"
+        cell.value = res['endTime']
         cell.font = Font(color="000000")
         cell.fill = PatternFill("solid", fgColor="eeeeee")
 
@@ -593,7 +695,7 @@ class ExcelRenderer:
         cell.fill = PatternFill("solid", fgColor="eeeeee")
 
         cell = ws['C13']
-        cell.value = "11.O"
+        cell.value = res['analysisRun']['version']
         cell.font = Font(color="000000")
         cell.fill = PatternFill("solid", fgColor="eeeeee")
 
@@ -607,7 +709,7 @@ class ExcelRenderer:
 
         ws.merge_cells('B1:Z2')
         cell = ws['B1']
-        cell.value = app_name.title()
+        cell.value = PLATFORM_ROUTE.title()
         cell.font = Font(color="00598B", bold=True)
         cell.fill = PatternFill("solid", fgColor="eeeeee")
         cell.alignment = Alignment(vertical="center")
@@ -640,7 +742,8 @@ class ExcelRenderer:
         """
         :return: Workbook
         """
-        self.generate_summary()
+        res = self.res
+        self.generate_summary(res)
         # run_data = self.analysis_run.get_result().get('excel-data', {})
         run_data = self.analysis_run
         for sheet in run_data['sheets']:
