@@ -4,7 +4,6 @@ import datetime
 import logging
 from io import BytesIO
 from datetime import datetime
-
 import json
 
 from urllib.request import urlopen
@@ -20,8 +19,6 @@ import boto3
 import flask
 import requests
 
-from .renderer.excel import ExcelRenderer
-from .models import Session, AnalysisRun, AnalysisSend
 from .constants import DATETIME_FORMAT
 logger = logging.getLogger(__name__)
 
@@ -32,6 +29,7 @@ API_SECRET = os.getenv('API_SECRET')
 BASE_API_URL = os.getenv('DATA_API_BASE_URL', '')
 PLATFORM_ROUTE = os.getenv("PLATFORM_ROUTE")
 
+from .renderer.excel import ExcelRenderer
 storage_name = os.getenv('STORAGE_NAME')
 
 global ACCESS_KEY_ID, SECRET_ACCESS_KEY, REGION_NAME, BUCKET_NAME
@@ -106,6 +104,7 @@ def get_user_id():
 def call_requests(method, url, params=None, data=None, json=None, verify=True):
     headers = get_headers()
     retry = 1
+    resp = None
     while retry <= API_RETRY:
         try:
             resp = requests.request(method, url, params=params, data=data, json=json, headers=headers, verify=verify)
@@ -119,7 +118,8 @@ def call_requests(method, url, params=None, data=None, json=None, verify=True):
             continue
 
         return resp
-
+    
+    return resp
 
 def call_get_requests(url, params=None, verify=True):
     return call_requests('GET', url, params, verify=verify)
@@ -128,18 +128,23 @@ def call_get_requests(url, params=None, verify=True):
 def call_post_requests(url, params=None, data=None, verify=True):
     return call_requests('POST', url, params, data, verify=verify)
 
+
 def is_authenticated():
+    logging.error(f'enter into authentication block')
     REQUIRE_AUTH_REDIRECT = os.getenv('REQUIRE_AUTH_REDIRECT') == 'true'
+    logger.info("<------------ REQUIRE_AUTH_REDIRECT -------> %s", REQUIRE_AUTH_REDIRECT)
     if not REQUIRE_AUTH_REDIRECT:
         return True
 
     url = f'{BASE_API_URL}/api/v2/users/me'
+    logger.info("<------------url---------------> %s ", url)
     res = call_get_requests(url)
-
+    logging.error(f'<------------res---------------> {res}')
     return res.status_code == 200
 
 
 def login_required(view):
+    logging.error(f'enter into login required block')
     '''Decorator that check authentication'''
   
     def wrap(*args, **kwargs):
@@ -154,20 +159,11 @@ def get_epoc_from_datetime_string(str_datetime):
     timestamp = datetime.strptime(str_datetime, DATETIME_FORMAT).timestamp()
     return timestamp
 
-def get_run_result(run_id, field=None, default_value=None):
-    with Session() as session:
-        run = session.query(AnalysisRun).filter_by(id=run_id).first()
-
-    result = run.get_result() if run else {}
-    if field:
-        result = result.get(field, default_value)
-
-    return result
 
 def get_result_by_run(run_id, field=None, default_value=None):
     try:
         s3 = get_s3_client()
-        run_id= f'analytics-apps/{PLATFORM_ROUTE}/json/{run_id}'
+        run_id= f'analytics-apps/{PLATFORM_ROUTE}/{run_id}/json/{run_id}'
         res_object = s3.get_object(Bucket=BUCKET_NAME,Key=run_id)
         serializedObject = res_object['Body'].read()
         result = json.loads(serializedObject)
@@ -179,14 +175,6 @@ def get_result_by_run(run_id, field=None, default_value=None):
         pass
 
 
-def get_run_params(run_id, field=None, default_value=None):
-    with Session() as session:
-        run = session.query(AnalysisRun).filter_by(id=run_id).first()
-
-    if run:
-        return run.params
-
-
 def get_ses_client():
     return boto3.client('ses',
                         region_name=REGION_NAME,
@@ -261,14 +249,14 @@ def generate_pdf(analysis_run):
     }
 
     res = requests.post(url, data=data).json()
-    logger.info('Pdf response is: %s', res)
-    return res
+    logger.info('Pdf response is: %s', res['Location'])
+    return res['Location']
 
 
 
-def generate_excel(analysis_run, file_name=None):
+def generate_excel(analysis_run, orgId, file_name=None):
     try:
-        excel_renderer = ExcelRenderer(analysis_run)
+        excel_renderer = ExcelRenderer(analysis_run, orgId)
         workbook = excel_renderer.render()
     except Exception as ex:
         raise ex
@@ -283,18 +271,28 @@ def generate_excel(analysis_run, file_name=None):
     return output
 
 
-def update_db_url(response, analysisRunId):
-        result_path=f'analytics-apps/{PLATFORM_ROUTE}/json/'
-        location=result_path + analysisRunId
-        result_url = upload_to_s3(json.dumps(response).encode(), location)
-        logger.info('Compute results url is %s', result_url)
+def update_results_url(json_result_url, gen_start_time, gen_completed_time, analysisRunId, CONFIGURE, tenantId, excel_result_url=None, pdf_result_url=None):
+    if CONFIGURE == 'test':
         url = BASE_API_URL + f'/api/v2/tenants/client_53/resources/{analysisRunId}'
         data={ 
-                "description" : result_url
+                "description" : json_result_url
+                # "csv_download_url" : excel_result_url,
+                # "pdf_download_url" : pdf_result_url,
+                # "rep_gen_start_time" : gen_start_time,
+                # "rep_gen_completed_time" : gen_completed_time
              }
-        
-        res = call_post_requests(url , data=json.dumps(data), verify=False);
-        logger.info('Database update response is %s', res)
+    else:
+        url = BASE_API_URL + f'/analyticsapps/api/v7/tenants/{tenantId}/analysisrun/id/{analysisRunId}'
+        data={
+                "resultUrl" : json_result_url,
+                "pdfDownloadUrl" : pdf_result_url,
+                "csvDownloadUrl" : excel_result_url,
+                "repGenStartTime" : gen_start_time,
+                "repGenEndTime" : gen_completed_time
+            }
+
+    res = call_post_requests(url , data=json.dumps(data), verify=False);
+    logger.info('Database update response is %s', res)
 
 
 #Upload excel file to s3
@@ -304,7 +302,9 @@ def upload_excel_s3(local_file, bucket, s3_file):
         s3.upload_file(local_file, bucket, s3_file)
         url = f'https://{bucket}.s3.{REGION_NAME}.amazonaws.com/{s3_file}'
         logger.info('Upload successful, result url is %s', url)
-        return True
+        
+        delete_excel_file(local_file)
+        return url
     except FileNotFoundError:
         logger.info('File was not found')
         return False
@@ -322,21 +322,17 @@ def delete_excel_file(source_path):
         logger.info(f'Failed to delete: %s : %s % {file_path, e.strerror}')
 
 
-
 #Generate excel file
-def generate_excel_file(run_id):
-    import time
-    import datetime
+def generate_excel_file(run_id, orgId):
     logger.info('Entered into excel generation process')
     excel_data=get_result_by_run(run_id, 'excel-data', {})
-    reportname = 'asset-insights' + '-' + datetime.datetime.now().strftime('%Y-%m-%d-%I-%M-%S') + '.xlsx'
+    reportname = f"{PLATFORM_ROUTE}" + '-' + datetime.now().strftime('%Y-%m-%d-%I-%M-%S') + '.xlsx'
     filepath = './' + reportname
-    generate_excel(excel_data, filepath)
-    excel_file_location = f'analytics-apps/{PLATFORM_ROUTE}/excel/' + reportname
+    generate_excel(excel_data, orgId, filepath)
+    excel_file_location = f'analytics-apps/{PLATFORM_ROUTE}/{run_id}/excel/' + reportname
     
-    upload_excel_s3(filepath, BUCKET_NAME, excel_file_location)
-    
-    #delete_excel_file(filepath)
+    excel_url = upload_excel_s3(filepath, BUCKET_NAME, excel_file_location)
+    return excel_url
 
 
 def upload_excel(analysis_run, excel_file):
